@@ -1,6 +1,6 @@
 import os
 import hub
-from typing import Optional, Union
+from typing import Dict, Optional, Union
 
 from hub.auto.unstructured.kaggle import download_kaggle_dataset
 from hub.auto.unstructured.image_classification import ImageClassification
@@ -41,7 +41,7 @@ class dataset:
         public: bool = False,
         memory_cache_size: int = DEFAULT_MEMORY_CACHE_SIZE,
         local_cache_size: int = DEFAULT_LOCAL_CACHE_SIZE,
-        creds: Optional[dict] = None,
+        creds: Optional[Union[Dict, str]] = None,
         token: Optional[str] = None,
         verbose: bool = True,
     ):
@@ -70,7 +70,7 @@ class dataset:
             public (bool): Defines if the dataset will have public access. Applicable only if Hub cloud storage is used and a new Dataset is being created. Defaults to True.
             memory_cache_size (int): The size of the memory cache to be used in MB.
             local_cache_size (int): The size of the local filesystem cache to be used in MB.
-            creds (dict, optional): A dictionary containing credentials used to access the dataset at the path.
+            creds (dict, str, optional): A dictionary containing credentials or path to credentials file used to access the dataset at the path.
                 If aws_access_key_id, aws_secret_access_key, aws_session_token are present, these take precedence over credentials present in the environment or in credentials file. Currently only works with s3 paths.
                 It supports 'aws_access_key_id', 'aws_secret_access_key', 'aws_session_token', 'endpoint_url', 'region', 'profile_name' as keys.
             token (str, optional): Activeloop token, used for fetching credentials to the dataset at path if it is a Hub dataset. This is optional, tokens are normally autogenerated.
@@ -463,14 +463,15 @@ class dataset:
         return src_ds.copy(
             dest,
             overwrite=overwrite,
-            dest_creds=dest_creds,
-            dest_token=dest_token,
+            creds=dest_creds,
+            token=dest_token,
             num_workers=num_workers,
             scheduler=scheduler,
             progressbar=progressbar,
         )
 
     @staticmethod
+    @hub_reporter.record_call
     def deepcopy(
         src: str,
         dest: str,
