@@ -5,6 +5,7 @@ from typing import Any, Dict, Optional
 import uuid
 
 from hub.client.config import REPORTING_CONFIG_FILE_PATH
+from hub.util.bugout_token import BUGOUT_TOKEN
 from humbug.consent import HumbugConsent
 from humbug.report import HumbugReporter
 
@@ -91,7 +92,7 @@ hub_reporter = HumbugReporter(
     consent=consent,
     client_id=client_id,
     session_id=session_id,
-    bugout_token="c880426a-e9ee-4207-b2cb-6b284b37d90b",
+    bugout_token=BUGOUT_TOKEN,
     tags=[],
 )
 
