@@ -1,3 +1,4 @@
+import numpy as np
 import hub
 
 
@@ -20,5 +21,9 @@ def test_read(cat_path, flower_path):
     assert flower.dtype == "uint8"
     assert flower.array.shape == (513, 464, 4)
 
+    arr = np.array(cat, dtype=np.uint32)
+    assert arr.shape == (900, 900, 3)
+    assert arr.dtype == np.uint32
+
 
 # TODO: test creating Sample with np.ndarray
