@@ -1,18 +1,16 @@
+from collections import defaultdict
 import math
 import warnings
 import hub
-from typing import Any, Dict, List, Tuple, Optional
+from typing import Any, Dict, List, Tuple
 from json.decoder import JSONDecodeError
+from hub.core.linked_chunk_engine import LinkedChunkEngine
 from hub.core.meta.tensor_meta import TensorMeta
-from hub.core.meta.encode.tile import TileEncoder
 from hub.core.storage import StorageProvider, MemoryProvider, LRUCache
 from hub.core.chunk_engine import ChunkEngine
-from hub.core.meta.encode.chunk_id import ChunkIdEncoder
 from hub.core.transform.transform_dataset import TransformDataset
 
 from hub.constants import MB, TRANSFORM_PROGRESSBAR_UPDATE_INTERVAL
-from hub.core.version_control.commit_chunk_set import CommitChunkSet
-from hub.core.version_control.commit_diff import CommitDiff
 from hub.util.remove_cache import get_base_storage
 from hub.util.keys import get_tensor_meta_key
 from hub.util.exceptions import (
@@ -25,14 +23,6 @@ from hub.util.exceptions import (
 import posixpath
 import time
 
-TransformOut = Tuple[
-    Dict[str, TensorMeta],
-    Dict[str, ChunkIdEncoder],
-    Dict[str, TileEncoder],
-    Dict[str, Optional[CommitChunkSet]],
-    Dict[str, CommitDiff],
-]
-
 
 def transform_sample(
     sample: Any,
@@ -100,18 +90,26 @@ def is_empty_transform_dataset(dataset: TransformDataset):
     return all(len(dataset[tensor]) == 0 for tensor in dataset.tensors)
 
 
-def store_data_slice(transform_input: Tuple) -> TransformOut:
+def store_data_slice(transform_input: Tuple) -> Dict:
     """Takes a slice of the original data and iterates through it and stores it in the actual storage.
     The tensor_meta and chunk_id_encoder are not stored to the storage to prevent overwrites/race conditions b/w workers.
     They are instead stored in memory and returned."""
     return store_data_slice_with_pbar(None, transform_input)
 
 
-def store_data_slice_with_pbar(pg_callback, transform_input: Tuple) -> TransformOut:
-    data_slice, inp = transform_input
-    output_storage, group_index, tensors, pipeline, version_state, skip_ok = inp
+def store_data_slice_with_pbar(pg_callback, transform_input: Tuple) -> Dict:
+    data_slice, output_storage, inp = transform_input
+    (
+        group_index,
+        tensors,
+        visible_tensors,
+        pipeline,
+        version_state,
+        link_creds,
+        skip_ok,
+    ) = inp
     all_chunk_engines = create_worker_chunk_engines(
-        tensors, output_storage, version_state
+        tensors, output_storage, version_state, link_creds
     )
 
     if isinstance(data_slice, hub.Dataset):
@@ -120,7 +118,7 @@ def store_data_slice_with_pbar(pg_callback, transform_input: Tuple) -> Transform
     transform_data_slice_and_append(
         data_slice,
         pipeline,
-        tensors,
+        visible_tensors,
         all_chunk_engines,
         group_index,
         pg_callback,
@@ -131,23 +129,30 @@ def store_data_slice_with_pbar(pg_callback, transform_input: Tuple) -> Transform
     all_tensor_metas = {}
     all_chunk_id_encoders = {}
     all_tile_encoders = {}
+    all_sequence_encoders = {}
     all_chunk_sets = {}
     all_commit_diffs = {}
+    all_creds_encoders = {}
     for tensor, chunk_engine in all_chunk_engines.items():
         chunk_engine.cache.flush()
         chunk_engine.meta_cache.flush()
         all_tensor_metas[tensor] = chunk_engine.tensor_meta
         all_chunk_id_encoders[tensor] = chunk_engine.chunk_id_encoder
         all_tile_encoders[tensor] = chunk_engine.tile_encoder
+        all_sequence_encoders[tensor] = chunk_engine.sequence_encoder
         all_chunk_sets[tensor] = chunk_engine.commit_chunk_set
         all_commit_diffs[tensor] = chunk_engine.commit_diff
-    return (
-        all_tensor_metas,
-        all_chunk_id_encoders,
-        all_tile_encoders,
-        all_chunk_sets,
-        all_commit_diffs,
-    )
+        all_creds_encoders[tensor] = chunk_engine.creds_encoder
+
+    return {
+        "tensor_metas": all_tensor_metas,
+        "chunk_id_encoders": all_chunk_id_encoders,
+        "sequence_encoders": all_sequence_encoders,
+        "tile_encoders": all_tile_encoders,
+        "commit_chunk_sets": all_chunk_sets,
+        "commit_diffs": all_commit_diffs,
+        "creds_encoders": all_creds_encoders,
+    }
 
 
 def _transform_sample_and_update_chunk_engines(
@@ -174,7 +179,9 @@ def _transform_sample_and_update_chunk_engines(
         raise TensorMismatchError(list(tensors), list(result_keys), skip_ok)
 
     for tensor, value in result.items():
-        all_chunk_engines[tensor].extend(value.numpy_compressed())
+        chunk_engine = all_chunk_engines[tensor]
+        callback = chunk_engine._transform_callback
+        chunk_engine.extend(value.numpy_compressed(), link_callback=callback)
 
 
 def transform_data_slice_and_append(
@@ -208,12 +215,12 @@ def transform_data_slice_and_append(
 
 
 def create_worker_chunk_engines(
-    tensors: List[str], output_storage: StorageProvider, version_state
+    tensors: List[str], output_storage: StorageProvider, version_state, link_creds
 ) -> Dict[str, ChunkEngine]:
     """Creates chunk engines corresponding to each storage for all tensors.
     These are created separately for each worker for parallel uploads.
     """
-    all_chunk_engines = {}
+    all_chunk_engines: Dict[str, ChunkEngine] = {}
     num_tries = 1000
     for tensor in tensors:
         for i in range(num_tries):
@@ -227,6 +234,7 @@ def create_worker_chunk_engines(
                 # this chunk engine is used to retrieve actual tensor meta and chunk_size
                 storage_chunk_engine = ChunkEngine(tensor, storage_cache, version_state)
                 existing_meta = storage_chunk_engine.tensor_meta
+
                 chunk_size = storage_chunk_engine.max_chunk_size
                 new_tensor_meta = TensorMeta(
                     htype=existing_meta.htype,
@@ -234,13 +242,28 @@ def create_worker_chunk_engines(
                     sample_compression=existing_meta.sample_compression,
                     chunk_compression=existing_meta.chunk_compression,
                     max_chunk_size=chunk_size,
+                    links=existing_meta.links,
+                    is_sequence=existing_meta.is_sequence,
+                    is_link=existing_meta.is_link,
+                    hidden=existing_meta.hidden,
+                    verify=existing_meta.verify,
                 )
                 meta_key = get_tensor_meta_key(tensor, version_state["commit_id"])
                 memory_cache[meta_key] = new_tensor_meta  # type: ignore
                 storage_cache.clear_cache()
-                storage_chunk_engine = ChunkEngine(
-                    tensor, storage_cache, version_state, memory_cache
-                )
+                if existing_meta.is_link:
+                    storage_chunk_engine = LinkedChunkEngine(
+                        tensor,
+                        storage_cache,
+                        version_state,
+                        link_creds,
+                        memory_cache,
+                    )
+                else:
+                    storage_chunk_engine = ChunkEngine(
+                        tensor, storage_cache, version_state, memory_cache
+                    )
+                storage_chunk_engine._all_chunk_engines = all_chunk_engines
                 all_chunk_engines[tensor] = storage_chunk_engine
                 break
             except (JSONDecodeError, KeyError):
@@ -268,6 +291,7 @@ def add_cache_to_dataset_slice(
         read_only=dataset_slice.read_only,
         token=dataset_slice.token,
         verbose=False,
+        link_creds=dataset_slice.link_creds,
     )
     dataset_slice.checkout(commit_id)
     return dataset_slice
@@ -290,17 +314,20 @@ def check_transform_data_in(data_in, scheduler: str) -> None:
             )
 
 
-def check_transform_ds_out(ds_out: hub.Dataset, scheduler: str) -> None:
+def check_transform_ds_out(
+    ds_out: hub.Dataset, scheduler: str, check_lengths: bool
+) -> None:
     """Checks whether the ds_out for a transform is valid or not."""
     if ds_out._read_only:
         raise InvalidOutputDatasetError
     tensors = list(ds_out.tensors)
 
-    for tensor in tensors:
-        if len(ds_out[tensor]) != len(ds_out):
-            raise InvalidOutputDatasetError(
-                "One or more tensors of the ds_out have different lengths. Transform only supports ds_out having same number of samples for each tensor (This includes empty datasets that have 0 samples per tensor)."
-            )
+    if check_lengths:
+        for tensor in tensors:
+            if len(ds_out[tensor]) != len(ds_out):
+                raise InvalidOutputDatasetError(
+                    "One or more tensors of the ds_out have different lengths. Transform only supports ds_out having same number of samples for each tensor (This includes empty datasets that have 0 samples per tensor)."
+                )
 
     output_base_storage = get_base_storage(ds_out.storage)
     if isinstance(output_base_storage, MemoryProvider) and scheduler not in [
@@ -319,10 +346,7 @@ def get_pbar_description(compute_functions: List):
     if num_funcs == 0:
         return "Evaluating"
 
-    func_names: List[str] = []
-    for transform_function in compute_functions:
-        func_names.append(transform_function.func.__name__)
-
+    func_names: List[str] = [f.name for f in compute_functions]
     if num_funcs == 1:
         return f"Evaluating {func_names[0]}"
 
@@ -370,6 +394,8 @@ def check_lengths(all_tensors_generated_length, skip_ok):
 
     first_length = None
     for length in all_tensors_generated_length.values():
+        if length == 0:
+            continue
         if first_length is None:
             first_length = length
         elif length not in [0, first_length]:
@@ -384,3 +410,14 @@ def sanitize_workers_scheduler(num_workers, scheduler):
         scheduler = "serial"
     num_workers = max(num_workers, 1)
     return num_workers, scheduler
+
+
+def process_transform_result(result: List[Dict]):
+    if not result:
+        return result
+    final = defaultdict(list)
+    keys = list(result[0].keys())
+    for item in result:
+        for key in keys:
+            final[key].append(item[key])
+    return final
